==> gnomeicu-0.96.1.tar.gz: gnomeicu-0.96.1/src/gtkfunc.h <==
/************************************
 Miscellaneous functions
 (c) 1999 Jeremy Wise
 GnomeICU  
*************************************/

#ifndef __GTKFUNC_H__
#define __GTKFUNC_H__

#include <gnome.h>

#include "common.h"

extern GtkWidget *found_list;
extern int start_new_info;

void animate_on( void );
void animate_off( void );
void icq_quit( GtkWidget *widget, gpointer data );
void icq_refresh( gpointer data, int sok, GdkInputCondition cond );
void icq_msgbox( STORED_MESSAGE_PTR message_text, UIN_T uin );
GtkWidget *create_menu ( void );
void show_contact_message( GSList *contact );
void icq_sendmessage( GtkWidget *button, gpointer data );
gint icq_sendmessage_window( GtkWidget *clist, GdkEventButton *event,
                             gpointer data );
void icq_sendmessage_window_from_menu( GtkWidget *widget, gpointer data );
int stay_connected( void );
void show_personal_info( GtkWidget *widget, gpointer data );
void dump_personal_info( UIN_T uin );
void authorize_uin( GtkWidget *widget, gpointer data );
void display_mess_history( GtkWidget *widget, gpointer data );
void read_next( GtkWidget *widget, gpointer data );
void send_chat_request( GtkWidget *widget, GtkWidget *entry );
void send_file_request( GtkWidget *widget, gpointer data );
void request_chat( GtkWidget *widget, gpointer data);
void open_message_chat( GtkWidget *widget, gpointer data );
void request_file( GtkWidget *widget, GList *files );
void request_file_default( GtkWidget *widget, gpointer data );
void send_url_window( GtkWidget *widget, char *defaulturl );
void send_url_window_default( GtkWidget *widget, gpointer data );
void remove_user( GtkWidget *widget, gpointer data );
void show_info_new( UIN_T uin );
void retrieve_away_message( GtkWidget *widget, gpointer data );
void retrieve_version( GtkWidget *widget, gpointer data );
void icq_set_status_online( GtkWidget *widget, gpointer data );
void icq_set_status_offline( GtkWidget *widget, gpointer data );
int icq_set_status_away( GtkWidget *widget, gpointer data );
void icq_set_status_na( GtkWidget *widget, gpointer data );
void icq_set_status_invisible( GtkWidget *widget, gpointer data );
void icq_set_status_dnd( GtkWidget *widget, gpointer data );
void icq_set_status_occ( GtkWidget *widget, gpointer data );
void icq_set_status_ffc( GtkWidget *widget, gpointer data );
void display_url( GtkWidget *widget, char *url );
void display_url_from_entry( GtkWidget *widget, GtkEntry *entry );
gint hide_dont_kill( GtkWidget *widget );
void add_from_search( GtkWidget *widget, gpointer data );
gint app_save_state_cb( GnomeClient *client, gint phase,
                        GnomeRestartStyle save_style, gint shutdown,
                        GnomeInteractStyle interact_style, gint fast,
                        gpointer client_data );
gint hide_ch_window( GtkWidget *widget, GdkEvent *event, GtkWidget *window );
int popup_status_menu( GtkWidget *widget, gpointer data );
gint ctrl_enter_cb( GtkWidget *widget, GdkEventKey *ev, int sock );

void request_file_action( GSList *completed_files );

#endif /* __GTKFUNC_H__ */

==> gnomeicu_0.98.2.orig.tar.gz: gnomeicu-0.98.2/src/gtkfunc.h <==
/************************************
 Miscellaneous functions
 (c) 1999 Jeremy Wise
 GnomeICU  
*************************************/

#ifndef __GTKFUNC_H__
#define __GTKFUNC_H__

#include <gnome.h>

#include "common.h"

extern GtkWidget *found_list;
extern int start_new_info;

void animate_on( void );
void animate_off( void );
void icq_msgbox( STORED_MESSAGE_PTR message_text, UIN_T uin );
GtkWidget *create_menu ( void );
gint icq_sendmessage_window( GtkWidget *clist, GdkEventButton *event, gpointer data );

void show_contact_message( GSList *contact );
void read_next( GtkWidget *widget, gpointer data );
void send_chat_request( GtkWidget *widget, GtkWidget *entry );
void send_file_request( GtkWidget *widget, gpointer data );
void send_url_window( GtkWidget *widget, char *defaulturl );
void remove_contact(UIN_T uin, gboolean rem_history);
void icq_set_status( GtkWidget *widget, gpointer data );
void icq_set_status_online( GtkWidget *widget, gpointer data );
void icq_set_status_offline( GtkWidget *widget, gpointer data );
int icq_set_status_away( GtkWidget *widget, gpointer data );
void icq_set_status_na( GtkWidget *widget, gpointer data );
void icq_set_status_invisible( GtkWidget *widget, gpointer data );
void icq_set_status_dnd( GtkWidget *widget, gpointer data );
void icq_set_status_occ( GtkWidget *widget, gpointer data );
void icq_set_status_ffc( GtkWidget *widget, gpointer data );
void display_url( GtkWidget *widget, char *url );
void display_url_from_entry( GtkWidget *widget, GtkEntry *entry );
gint hide_dont_kill( GtkWidget *widget );
gint app_save_state_cb( GnomeClient *client, gint phase,
                        GnomeRestartStyle save_style, gint shutdown,
                        GnomeInteractStyle interact_style, gint fast,
                        gpointer client_data );
gint hide_ch_window( GtkWidget *widget, GdkEvent *event, GtkWidget *window );
int popup_status_menu( GtkWidget *widget, gpointer data );
gint ctrl_enter_cb( GtkWidget *widget, GdkEventKey *ev, int sock );
void grab_history( GtkWidget *widget, gpointer data );
void request_file_action( GSList *completed_files );

#endif /* __GTKFUNC_H__ */
